get_intersection_genes: get_intersection_genes

View source: R/mod_sets_fct_sets_functions.R

get_intersection_genesR Documentation

get_intersection_genes

Description

get the genes at the intersection of selected sets

Usage

get_intersection_genes(mat, sets)

Arguments

mat

binary set membership matrix (ComplexHeatmap)

sets

vector of names of sets for which you want the intersection

Value

character vector of gene names


CECADBioinformaticsCoreFacility/degSets documentation built on July 29, 2022, 7:54 p.m.