View source: R/mod_sets_fct_sets_functions.R
| get_intersection_genes | R Documentation |
get the genes at the intersection of selected sets
get_intersection_genes(mat, sets)
mat |
binary set membership matrix (ComplexHeatmap) |
sets |
vector of names of sets for which you want the intersection |
character vector of gene names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.